{{- define "imageSecret" -}}
  {{- if .Values.imageSecrets.enabled -}}
      {{- with .Values.imageCredentials }}
      {{- printf "{\"auths\":{\"%s\":{\"username\":\"%s\",\"password\":\"%s\",\"email\":\"%s\",\"auth\":\"%s\"}}}" .registry .username .password .email (printf "%s:%s" .username .password | b64enc) | b64enc }}
  {{- end -}}
{{- end }}
{{- end }}

{{/*
имя wist сервера
*/}}
{{- define "wiststore.wist_fullname" -}}
{{- printf "%s-%s" "wist" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
имя store сервера
*/}}
{{- define "wiststore.store_fullname" -}}
{{- printf "%s-%s" "web" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
имя proxy сервера
*/}}
{{- define "wiststore.proxy_fullname" -}}
{{- printf "%s-%s" "proxy" .Release.Name  | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "wiststore.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "wiststore.labels" -}}
helm.sh/chart: {{ include "wiststore.chart" . }}
{{ include "wiststore.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "wiststore.selectorLabels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app: {{ include "wiststore.wist_fullname" . }}
run: wist
{{- end }}

{{/*
 метка store
*/}}
{{- define "wiststore.store-labels" -}}
{{ include "wiststore.labels" . }}
app.kubernetes.io/component: store
{{ include "wiststore.store-selectorLabels" . }}
{{- end }}

{{/*
Selector store
*/}}
{{- define "wiststore.store-selectorLabels" -}}
app: {{ include "wiststore.store_fullname" . }}
run: store
{{- end }}

{{/*
 метка proxy
*/}}
{{- define "wiststore.proxy-labels" -}}
{{ include "wiststore.labels" . }}
app.kubernetes.io/component: proxy
{{ include "wiststore.proxy-selectorLabels" . }}
{{- end }}

{{/*
Selector proxy
*/}}
{{- define "wiststore.proxy-selectorLabels" -}}
app: {{ include "wiststore.proxy_fullname" . }}
run: proxy
{{- end }}

{{/*
Имя configMap для wist
*/}}
{{- define "wiststore.wist-config" -}}
{{- printf "%s-%s-%s" "wist" .Release.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для proxy
*/}}
{{- define "wiststore.proxy-config" -}}
{{- printf "%s-%s-%s" "proxy" .Release.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Return  the proper Storage Class
*/}}
{{- define "wiststore.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}
